
#ifndef _AK_H
#define _AK_H

/************************************************************************
 *
 * File: Ak.h
 *
 * Copyright (c) 1995 by Rensselaer Polytechnic Institute,
 *                       Troy, NY 12180
 *
 * Created:       Wed Oct 11 18:48:00 1995 by James Miller
 * Last Modified: Mon Apr  8 11:22:16 1996 by James Miller
 *
 * Class to maintain the matrix of ak = E[uk] values.  This table
 * is stored as class data, with routines to build and read data values.
 *
 * E[uk] is the expected value of the kth absolute residual from a
 * Gaussian distribution with a standard deviation of 1 (and mean 0).
 *
 * An instance of the table is needed to access the values, if the
 * instance is the first created, then the static table is built,
 * otherwise nothing happens.  There is no instance data.
 *
 * Note that the table is indexed as ak[k][N].  This will return
 * the E[uk] when the population size is N.  k and N must be greater
 * than 0, and k must be less than or equal to N. Due to this indexing
 * notation, care must be taken not to overwrite the table.
 *
 *
 ************************************************************************/

#ident "@(#)Ak.h	1.2 96/04/08 RPI"

#ifndef bool
#include <bool.h>
#endif
#include "misc.h"

class Ak  {
  public:
    Ak(){ if (!built)  build(); };	
    virtual ~Ak(){};	

    double* operator[] (int row) const;
    
  protected:	
    static void build();

    static double table[MAX_N+1][MAX_N+1];
    static bool built;
    
};

#endif /* _AK_H */
