
#ifndef _E_S_K_H
#define _E_S_K_H

/************************************************************************
 *
 * File: E_s_k.h
 *
 * Copyright (c) 1995 by Rensselaer Polytechnic Institute,
 *                       Troy, NY 12180
 *
 * Created:       Wed Oct 11 19:09:45 1995 by James Miller
 * Last Modified: Mon Apr  8 11:22:43 1996 by James Miller
 *
 * Class to maintain the matrix of E[min s | k] values.  This table
 * is stored as class data, with routines to build and read data values.
 *
 * E[min s | k] is the expected value of s given that the minimum occurs at 
 * the kth absolute residual. E[min s | k] was calculated assuming a Gaussian
 * distribution with a standard deviation of 1 (and mean 0).
 *
 * This table is read from disk E_s_k.table
 *
 * An instance of the table is needed to access the values, if the
 * instance is the first created, then the static table is read,
 * otherwise nothing happens.  There is no instance data.
 *
 * Note that the table is indexed as esk[k][N].  This will return
 * the E[min s | k] when the population size is N.  k and N must be greater
 * than 0, and k must be less than or equal to N. Due to this indexing
 * notation, care must be taken not to overwrite the table.
 *
 ************************************************************************/

#ident "@(#)E_s_k.h	1.3 96/04/08 RPI"

#ifndef bool
#include <bool.h>
#endif

#include "misc.h"

class E_s_k  {
 public:	
  E_s_k(){ if (!built)  build(); };	
  virtual ~E_s_k(){};	

  double* operator[] (int row) const;
  int     max_N() {return maximum_N; };   // size of the table that was read.
  
 protected:	
  static void build();

  static double table[MAX_N+1][MAX_N+1];
  static bool built;
  static int maximum_N;
  
};

#endif /* _E_S_K_H */
