
#ifndef _MISC_H
#define _MISC_H

/************************************************************************
 *
 * File: misc.h
 *
 * Copyright (c) 1995 by Rensselaer Polytechnic Institute,
 *                       Troy, NY 12180
 *
 * Created:       Thu Oct  5 11:11:54 1995 by James Miller
 * Last Modified: Tue Apr  2 10:54:49 1996 by James Miller
 *
 * Miscellaneous matrix and math routines, the majority of which are
 * from "Numerical Recipes in C: The Art of Scientific Computing"
 *
 * gaussian_cdf_inv() is an adaptation of a routine provided by Robert W.
 * Cox from the Biophysics Research Institute at the Medical College of
 * Wisconsin.
 *
 ************************************************************************/

#ident "@(#)misc.h	1.4 96/04/04 RPI"

// hack for the Apogee C++ compiler, APOGEE identifier set in Makefile
#ifdef APOGEE
#ifndef M_SQRT2
#define M_SQRT2 1.41421356237309504880
#define M_2_SQRTPI 1.12837916709551257390
#endif
#endif



#define MAX_N 256

#define MY_MIN(A,B) ((A) < (B) ? (A) : (B))
#define MY_MAX(A,B) ((A) > (B) ? (A) : (B))
  

extern double erf1( double x );
extern double erfc( double x );
extern double erfcc( double x );
extern double gammp( double a, double x);
extern double gammq( double a, double x );
extern double gammln( double xx );
extern void   gcf( double * gammcf, double a, double x, double * gln);
extern void   gser( double * gamser, double a, double x, double * gln);
extern void   nrerror( char error_text[] );

extern double betai(double a, double b, double x);
extern double betacf(double a, double b, double x);

extern float *fvector(int, int);
extern double *dvector(int, int);
extern float **fmatrix(int, int, int, int);
extern double **dmatrix(int, int, int, int);
extern int *ivector(int, int);

extern float *re_fvector(float *, int, int, int, int);
extern double *re_dvector(double *, int, int, int, int);
extern float **re_fmatrix(float **, int, int, int, int, int, int, int, int);
extern double **re_dmatrix(double **, int, int, int, int, int, int, int, int);
extern int *re_ivector(int*, int, int, int, int);

extern void free_fvector(float *, int, int);
extern void free_dvector(double *, int, int);
extern void free_ivector(int *, int, int);
extern void free_fmatrix(float **, int, int, int, int);
extern void free_dmatrix(double **, int, int, int, int);

extern void ludcmp(double **, int, int *, double *);
extern void lubksb(double **, int, int *, double *);

extern void svdcmp(double **, int, int, double *, double **);
extern void svbksb(double **, double *, double **, int, int,
		   double *, double *);

extern double gaussian_cdf_inv( double p );

#endif /* _MISC_H */












